@@ -1,14 +1,7 @@
-import glob
-import os
 import re
-import uuid
-import json
-import karray as ka
 from typing import Callable
 from .utils import load_scenario_info, _get_files_path_list, select_scenario_files
 
-from .settings import settings, allowed_string
-
 
 class DataCollection:
     def __init__(self):
@@ -214,96 +207,3 @@ class DataCollection:
 
     def __repr__(self):
         return '''DataCollection()'''
-
-
-class SymbolsHandler:
-    def __init__(self, method:str, folder_path:str=None, obj:DataCollection=None):
-        ''' 
-        method: "folder" or "object"
-        kwargs:
-            folder_path: path to folder with symbol files
-            object: DataCollection object
-        '''
-        assert isinstance(method, str), "Arg 'method' must be a string."
-        assert method in ["folder", "object"], "Arg 'method' must be either 'folder' or 'object'"
-        self.method = method
-        self.folder_path = None
-        self.symbols_book = None
-        self.symbol_handler_token = str(uuid.uuid4()) # TODO: this can be changed by hashing the input file
-        self.saved_symbols = {}
-        self.token_info = None
-        self.input_method(method=method, folder_path=folder_path, obj=obj)
-
-    def input_method(self, method:str, **kwargs):
-        if method == "object":
-            self.from_object(obj=kwargs['obj'])
-        elif method == "folder":
-            self.from_folder(folder_path=kwargs['folder_path'])
-        else:
-            raise Exception('A method mus be provided from either "object" or "folder"')
-
-    def from_object(self, obj:DataCollection):
-        self.symbols_book = obj.symbols_book
-        self.collector = obj.collector
-        self.short_names = obj.short_names
-        for n_v in self.symbols_book:
-            settings.append((*n_v,self.symbol_handler_token))
-
-
-    def from_folder(self, folder_path:str=None):
-        self.token_info = {}
-        self.folder_path = folder_path
-        files = glob.glob(os.path.join(self.folder_path, "*.feather"))
-        self.symbols_book = {}
-        for file in files:
-            loaded_file_dict = from_feather_dict(file)
-            self.symbols_book[(loaded_file_dict['name'],loaded_file_dict['value_type'])] = file
-
-            token = loaded_file_dict['symbol_handler_token']
-            settings.append((loaded_file_dict['name'],loaded_file_dict['value_type'],loaded_file_dict['symbol_handler_token']))
-
-            if token not in self.token_info:
-                self.token_info[token] = {}
-            self.token_info[token][(loaded_file_dict['name'],loaded_file_dict['value_type'])] = file
-        if len(self.token_info) > 1:
-            print(f"There are Symbols' files with different symbol_handler_token in {folder_path}")
-            print("       Symbol's scenario short names or id's might be in conflict.")
-            print("       Make sure all Symbols are from the same symbol_handler_token")
-            print("       Otherwise, it may happen, for example, different scenarios have the same id.")
-            print("       See 'token_info' attribute of SymbolsHandler for more information")
-
-
-    def append(self, **kwargs):
-        for name in kwargs:
-            symbol = kwargs[name]
-            assert len(set(name).difference(set(allowed_string))) == 0, f"Symbol name '{name}' contains special characters. Please, change the name of the symbol. Allowed chars are: {allowed_string}"
-            symbol.name = name
-            self.saved_symbols[(name, symbol.value_type)] = symbol
-
-    def save(self, folder_path=None):
-        if folder_path is None:
-            assert self.folder_path is not None, "folder_path must be provided"
-            folder_path = self.folder_path
-        os.makedirs(folder_path, exist_ok=True)
-        for symbol in self.saved_symbols.values():
-            file_name = f"{symbol.name}.{symbol.value_type}.{symbol.symbol_handler_token}.feather"
-            file_path = os.path.join(folder_path,file_name)
-            symbol.to_feather(file_path)
-
-    def get_info(self, symbol_name, value_type):
-        assert (symbol_name, value_type) in self.symbols_book, f"Pairs {(symbol_name, value_type)} not present in the symbols_book attribute of SymbolsHandler"
-        if isinstance(self.symbols_book[(symbol_name, value_type)], dict):
-            return self.symbols_book[(symbol_name, value_type)]
-        elif isinstance(self.symbols_book[(symbol_name, value_type)], str):
-            return self.symbols_book[(symbol_name, value_type)]
-
-    def __repr__(self):
-        return f'''SymbolsHandler(method='{self.method}')'''
-
-# TODO: metadata dictionary keys are always strings. Needs to be fixed
-def from_feather_dict(path):
-    arr, restored_table = ka.from_feather(path, with_table=True)
-    custom_meta_key = 'symbolx'
-    restored_meta_json = restored_table.schema.metadata[custom_meta_key.encode()]
-    restored_meta = json.loads(restored_meta_json)
-    return dict(array=arr,**restored_meta)
\ No newline at end of file
