@@ -37,7 +37,7 @@ def symbol_parser_csv(folder: str, symbol_names: list=[], zip_extension=None, **
             symbol_list.append(symbol_dict)
     return symbol_list
 
-def load_csv(path:str, symbol_name:str, keep_zeros:bool, zip_extension=None, **kwargs):
+def load_csv(path:str, symbol_name:str, zip_extension=None, **kwargs):
     '''
     Load custom csv file.
     '''
@@ -75,7 +75,7 @@ def load_csv(path:str, symbol_name:str, keep_zeros:bool, zip_extension=None, **k
                     coords = None
             else:
                 coords=None
-        return {'data': (index, value), 'coords': coords, 'keep_zeros': keep_zeros}
+        return {'data': (index, value), 'coords': coords}
     else:
         folder = os.path.dirname(path)
         file_name = symbol_name
@@ -105,5 +105,5 @@ def load_csv(path:str, symbol_name:str, keep_zeros:bool, zip_extension=None, **k
                 coords = json.load(jsonfile)
         else:
             coords=None
-        return {'data': (index, value), 'coords': coords, 'keep_zeros': keep_zeros}
+        return {'data': (index, value), 'coords': coords}
 
